<?php

namespace Onestartup\Product\Controller;

use Illuminate\Http\Request;
use App\Http\Requests;
use App\Http\Controllers\Controller;
use Yajra\Datatables\Datatables;
use Onestartup\Product\Model\ProductCategory as Category;
use Onestartup\Product\Model\ProductImage as Gallery;
use Onestartup\Product\Model\Product;

class AdminProductController extends Controller
{
    public function index()
    {
        return view('product::product.index');
    }

    /**
     * Show the form for creating a new resource.
     * @return Response
     */
    public function create()
    {
        $categories = Category::pluck('name', 'id');

        return view('product::product.create')
            ->with('categories', $categories);
    }

    /**
     * Store a newly created resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function store(Request $request)
    {
        
        $product = new Product($request->all());
        $product->save();

        return redirect()
                ->route('admin.product.edit', $product->id)
                ->with('message_success', "Producto guardado correctamente, continua agregando las imagenes correspondientes");
    }

    /**
     * Show the form for editing the specified resource.
     * @return Response
     */
    public function edit($id)
    {
        $product = Product::find($id);
        $categories = Category::pluck('name', 'id');

        return view('product::product.edit')
            ->with('categories', $categories)
            ->with('product', $product);
    }

    /**
     * Update the specified resource in storage.
     * @param  Request $request
     * @return Response
     */
    public function update(Request $request, $id)
    {
        $product = Product::find($id);
        $product->fill($request->all());
        $product->save();

        return redirect()
            ->back()
            ->with('message_info', 'Información actualizada correctamente');
    }

    /**
     * Remove the specified resource from storage.
     * @return Response
     */
    public function destroy($id)
    {
        $product = Product::find($id);
        $product->delete();

        return redirect()
            ->back()
            ->with('message_danger', 'Producto eliminada correctamente');
    }

    public function getProducts()
    {

        $products = Product::select([
            'id',
            'name',
            'slug', 
            'category_id', 
            'created_at', 
            'description', 
            'features', 
            'specifications'
        ]);

        return Datatables::of($products)
            ->addColumn('main', function ($product) {
                return 
                        "<p class='mb0'>Nombre: <b>$product->name</b></p>".
                        "<p class='mb0'>Slug: <b>$product->slug</b></p>".
                        "<p class='mb0'>Categoria: <b>".$product->category->name."</b></p>".
                        "<p class='mb0'>Fecha creación: <b>".$product->created_at->format('d/m/Y')."</b></p>";
            })
            ->addColumn('form', function ($product) {
                return "<form method='POST' action='".route('admin.product.destroy',$product->id)."'>".
                "<input name='_method' type='hidden' value='DELETE' class='has-value'>".
                csrf_field() .
                "<button class='btn btn-danger btn-xs button-mb' onclick='return confirm();' type='submit'>".
                "<i class='fas fa-trash-alt icon-special-size'></i>Eliminar</button>".
                "</form>".
                "<a href='".route('show.product', $product->slug)."' class='btn btn-xs info button-mb' target='new'>".
                "<i class='fas fa-eye icon-special-size'></i>Ver</a>".
                "<br><a href='".route('admin.product.edit', $product->id)."' class='btn btn-xs accent mb0'>".
                "<i class='fas fa-edit icon-special-size'></i>Editar</a>";
            })
            ->rawColumns(['main', 'description', 'features', 'specifications', 'form'])
            ->make();
        
    }

    public function storeGallery(Request $request, $product_id)
    {
        $product = Product::find($product_id);

        $asset = '/storage/product/'.$product->id.'/gallery/';
        $path = public_path().$asset;
        $files = $request->file('file');

        foreach($files as $file){
            $fileName = $file->getClientOriginalName();
            $nombre_file = str_replace(' ', '_', $fileName);
            $file->move($path, $nombre_file);
            $gallery = new Gallery([
                'path'=>$asset.$nombre_file
            ]);

            $product->images()->save($gallery);
        }


        return $product;
    }

    public function deleteImage($id)
    {
        $gallery = Gallery::find($id);
        unlink(public_path().$gallery->path);
        $gallery->delete();

        return redirect()
            ->back()
            ->with('message_danger', 'Imagen eliminada correctamente');

    }

}
